# vim: set sw=4 ts=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2014 B1 Systems GmbH, Vobhurg, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/

Name:           handbrake
Version:        0.10.1
Release:        2.3
License:        GPL-2.0+
Summary:        Multithreaded Video Transcoder
Url:            http://handbrake.fr/
Group:          Productivity/Multimedia/Video/Editors and Convertors
# svn://svn.handbrake.fr/HandBrake/trunk#%{rev}
#Source:        HandBrake-svn%{rev}.tar.bz2
Source:         http://prdownloads.sourceforge.net/handbrake/HandBrake-%{version}.tar.bz2
Source101:      http://download.handbrake.fr/handbrake/contrib/fdk-aac-v0.1.1-6-gbae4553.tar.bz2
Source102:      http://download.handbrake.fr/handbrake/contrib/cmake-3.0.1.tar.gz
Source103:      http://download.handbrake.fr/handbrake/contrib/libav-v10.1.tar.bz2
Source104:      http://download.handbrake.fr/handbrake/contrib/libdvdnav-5.0.1-0-gaa3659d.tar.gz
Source105:      http://download.handbrake.fr/handbrake/contrib/libdvdread-5.0.0-6-gcb1ae87.tar.gz
Source106:      http://download.handbrake.fr/contrib/libmfx-v2014.tar.bz2
Source107:      http://download.handbrake.fr/contrib/libvpx-v1.3.0.tar.bz2
Source108:      http://download.handbrake.fr/contrib/x265-9329-0d30d2641875-1.5.tar.bz2
Source109:      http://download.handbrake.fr/handbrake/contrib/libbluray-0.5.0.tar.bz2
##
## libdvnav has "assert(0)" as default in some error paths, which is a nop with -DNDEBUG...
Source200:      libdvdnav-5.0.1-noreturninnonvoidfunction.patch
Source99:       handbrake-rpmlintrc

Patch0:         HandBrake-0.10.0-no-builddate.patch
Patch1:         handbrake-enable_local_fribidi.patch
BuildRequires:  python
# no longer: curl wget subversion
BuildRequires:  libbz2-devel zlib-devel libgudev-1_0-devel
%if 0%{?suse_version} > 1230
BuildRequires:  gtk3-devel >= 3.10
BuildRequires:  gtkhtml-devel
%endif
BuildRequires:  fribidi-devel
BuildRequires:  dbus-1-glib-devel
BuildRequires:  libicu-devel libnotify-devel
%if 0%{?suse_version} <= 1140
BuildRequires:  hal-devel
BuildRequires:  libwebkit-devel
BuildRequires:  gstreamer-0_10-devel gstreamer-0_10-plugins-base-devel
%else
BuildRequires:  libwebkitgtk3-devel
BuildRequires:  gstreamer-devel gstreamer-plugins-base-devel
%endif
BuildRequires:  sqlite3-devel libcurl-devel libxslt-devel
BuildRequires:  gcc gcc-c++ make glibc-devel yasm nasm
BuildRequires:  autoconf automake libtool intltool
BuildRequires:  update-desktop-files
BuildRequires:  libvorbis-devel libass-devel x264-devel libmp3lame-devel libtheora-devel
BuildRequires:  libsamplerate-devel

%description
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

%package cli
Summary:        Multithreaded Video Transcoder
Group:          Productivity/Multimedia/Video/Editors and Convertors
Obsoletes:      handbrake-unstable-cli < %{version}

%description cli
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

This package contains a command-line interface for Handbrake.

%if 0%{?suse_version} > 1230
%package gtk
Summary:        Multithreaded Video Transcoder
Group:          Productivity/Multimedia/Video/Editors and Convertors
Obsoletes:      handbrake-unstable-gtk < %{version}

%description gtk
HandBrake is an open-source, GPL-licensed, multiplatform, multithreaded video
transcoder.

This package contains a GTK+ graphical user interface for Handbrake.
%endif

%prep
%if 0%{?rev:1}
%setup -q -n "HandBrake-svn%{rev}"
%else
%setup -q -n "HandBrake-%{version}"
%endif
%patch0 -p1

%if 0%{?suse_version} < 1200
%patch1 -p1
%endif

# Copy 3rd party dependencies into expected locations:
%__mkdir download
for f in \
%{S:101} %{S:102} %{S:103} \
%{S:104} %{S:105} %{S:106} \
%{S:107} %{S:108} %{S:109} \
; do
    %__ln_s "$f" download/
done

# check beforehand that the versions match what the
# build system expects:
missing=$PWD/.missing
%__grep -hE '\.FETCH\.url *=' contrib/*/module.defs \
| %__awk -F' =' '{print $2}' \
| while read url; do
    f=$(echo "$url" | sed 's|^.*/||')
    case $f in
        bzip2*|libiconv*|pthreads*|zlib*) continue ;;
        autoconf*|automake*|libtool*|m4*) continue ;;
        pkg-config*)                      continue ;;
        fontconfig*|freetype*|fribidi*|libass*) continue ;;
        libogg*|libtheora*|libvorbis*|libsamplerate*) continue ;;
        libxml2*)                         continue ;;
        x264*|lame*)                      continue ;;
        yasm*)                            continue ;;
        mingw-libgnurx*)                  continue ;;
    esac
    [ -e "download/$f" ] || echo "$url">>"$missing"
done

if test -e "$missing"; then
    echo "ERROR: missing contrib source archives:" >&2
    cat "$missing" >&2
    exit 1
fi


%build
export CFLAGS="%{optflags} -fno-strict-aliasing -Wno-unused"
export CXXFLAGS="$CFLAGS -Wno-reorder"
export PATH="%{_builddir}/HandBrake-%{version}/build/contrib/bin:$PATH"

cp %{S:200} contrib/libdvdnav/A99-fix-missing-return-in-nonvoid-function.patch

# try to remove build date from binaries... -- seife+obs@b1-systems.com
PKGDATE=$(date -r %{_sourcedir}/handbrake.changes +%Y%m%d)
sed -i -e "s/@BUILD@/$PKGDATE/" make/configure.py
# we do not depend on curl or wget -- because everything is already here.
sed -i -e '/FETCH\.select/d' make/configure.py

%__mkdir build
./configure \
    --force \
    --build="$PWD/build" \
    --prefix="%{_prefix}" \
    --strip="/bin/true" \
    --optimize=speed \
%if 0%{?suse_version} <= 1230
    --disable-gtk \
%endif
    --debug=std ### debug=max removes -DNDEBUG from ffmpeg, leading to asserts aborting build...

pushd build
#### get rid of __DATE__ and __TIME__ in fdk-aac
%__mkdir contrib
%__mkdir contrib/fdkaac
tar -xf %{S:101} -C contrib/fdkaac
find contrib/fdkaac/ -type f | xargs sed -i -e "s/__DATE__/\"$PKGDATE\"/"
find contrib/fdkaac/ -type f | xargs sed -i -e 's/__TIME__/"00:00:00"/'
touch contrib/fdkaac/.stamp.extract
pushd contrib/fdkaac/fdk-aac-v0.1.1-6-gbae4553
autoreconf -fi
popd

%__make libhb/project.h
%__make %{?_smp_mflags} V=1

popd #build


%install
pushd build
%__make install DESTDIR=%{buildroot}
popd #build

if [ -e %{buildroot}%{_bindir}/ghb ]; then
    %__ln_s ghb "%{buildroot}%{_bindir}/HandBrakeGUI"
fi

%suse_update_desktop_file -r ghb AudioVideo AudioVideoEditing

# -f because it might not be there if built without gtk...
%__rm -f "%{buildroot}%{_datadir}/icons"/*/*.cache

## non-standard locales -- just remove to make rpmlint happy
rm -fr %{buildroot}/usr/share/locale/{ja_JP,no,ro_RO}

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files cli
%defattr(-,root,root)
%doc AUTHORS COPYING CREDITS NEWS THANKS
%{_bindir}/HandBrakeCLI

%if 0%{?suse_version} > 1230
%files gtk
%defattr(-,root,root)
%doc AUTHORS COPYING CREDITS NEWS THANKS
%{_bindir}/HandBrakeGUI
%{_bindir}/ghb
%{_datadir}/applications/ghb.desktop
%{_datadir}/icons/*/*/apps/hb-icon.*
/usr/share/locale/*/LC_MESSAGES/ghb.mo
%endif

%changelog
* Tue Apr 21 2015 seife+obs@b1-systems.com
- switch to gstreamer-1.0 instead of old gstreamer-0.10 for
  distributions newer than openSUSE 11.4
* Sun Apr 19 2015 seife+obs@b1-systems.com
- update to 0.10.1:
  - various bug fixes for all platforms and the core engine
  - updated x265 to 1.5 which brings numerous bug fixes and some
  performance improvements
- do not buildrequire wget, curl, subversion -- it's not needed
- fix --prefix and DESTDIR usage to avoid build paths in binaries
  and thus unnecessary republishing
* Tue Dec  2 2014 seife+obs@b1-systems.com
- fix "no return in nonvoid function" compiler error from embedded
  libdvdnav libdvdnav-5.0.1-noreturninnonvoidfunction.patch
* Tue Dec  2 2014 seife+obs@b1-systems.com
- adjust debug config from max to std to avoid ffmpeg assert aborts
* Tue Nov 25 2014 seife+obs@b1-systems.com
- update to 0.10.0:
- remove obsolete patches, update support tarballs, only add
  the really needed stuff
- more build date removal
- important change: due to GTK3 version dependencies, the GUI
  is only built for distributions newer than openSUSE 12.3
* Fri Apr 18 2014 seife+obs@b1-systems.com
- remove build date from binaries to avoid republishing
* Sun Dec  1 2013 obs@botter.cc
- add patch to fix compiling libx264: HandBrake-0.9.9_libx264-gcc-488-fix.patch
  add -fno-aggressive-loop-optimizations to extra-cflags in
  configure for >= 13.1, see also
  https://bugs.launchpad.net/ubuntu/+source/x264/+bug/1241772
  MAY BE REMOVED on upstream fix
* Thu Jun 13 2013 dnh@opensuse.org
- update to 0.9.9
  * replace harfbuzz patch by script fragement in spec
  * update yasm, libbluray, x264, replace ffmpeg by libav
  * remove tarballs that can be system-libs
* Sat Apr  6 2013 dnh@opensuse.org
- fix conflicts with harfbuzz headers for oS >= 12.3
  see https://pmbs.links2linux.org/request/show/425
* Sun Oct  7 2012 i@marguerite.su
- update to 0.9.8
  * Corrects a few crash bugs that showed up in 0.9.7
  * Includes an AppleTV3 Preset and updated iPad Preset (0.9.7)
* Thu Mar  1 2012 pascal.bleser@opensuse.org
- update to 0.9.6
* Thu Jul  7 2011 malcolmlewis@opensuse.org
- Add BuildRequires libgudev-1_0-devel as build failing with
  'No package 'gudev-1.0' found' error.
* Tue Jan  4 2011 pascal.bleser@opensuse.org
- update to 0.9.5
* Tue Sep 21 2010 pascal.bleser@opensuse.org
- update to trunk revision 3549:
  * try other gstreamer sink interfaces if gconfvideosink fails; it appears that gconfvideosink may not work on kde systems
  * remove the 8 audio limit
  * fix cli issue with batch scan and encode
  * fix a crash when a TS has no aspect ratio set in the video stream
  * bump ffmpeg from 22950 to 25082
  * fix a rare hang in the muxer
  * GUI: fix UI problem with trellis cavlc
  * add Bluray support:
    + unencrypted BD directory trees only
    + doesn't support iso images
    + also, no PGS subtitle support yet
  * chapters and angles are supported
  * fixes memory leak during scan
  * x264 bump from r1698 to r1713:
    + introduces trellis and psy-trellis for cavlc
  * GUI: simplify source selection dialog
  * fix muxing problem with certain sources/settings
* Thu Aug 19 2010 pascal.bleser@opensuse.org
- update to SVN trunk revision 3482:
  * x264 bump from r1681 to r1698: various bugfixes and improvements
* Sat Aug  7 2010 pascal.bleser@opensuse.org
- update to SVN trunk revision 3473, as requested by upstream
* Fri Nov 27 2009 pascal.bleser@opensuse.org
- update to 0.9.4
* Sun Nov  1 2009 pascal.bleser@opensuse.org
- update to snapshot 2907
* Thu Oct  1 2009 pascal.bleser@opensuse.org
- downgrade to snapshot rev 2845 as per upstream request
- fix version display
- use upstream compiler flags as per upstream request
* Fri Sep 25 2009 pascal.bleser@opensuse.org
- update to rev 2844:
  * [2844] bump libtheora to official 1.1 release
  * [2843] fix srt track stop time; srt stop time was being set to the end of the start chapter instead of the end of the stop chapter
  * [2842] theora: improvements to our theora implementation:
    + support 2-pass mode which is new to theora 1.1
    + set soft target rate control so that single pass abr behaves more like theora 1.0 and doesn't look quite so awful
  * [2841] don't remove srt subs when changing from mkv to mp4
  * [2836] bump x264 to r1271 make changes required by the x264 api change fix some build issues that the x264 bump exposed
  * [2831] fix bug that was causing one sec. of audio to be dropped on many ffmpeg files
* Mon Sep 14 2009 pascal.bleser@opensuse.org
- update to rev 2822:
  * [2821] dvdnav: improved patch that guarantees forward seek moves position forward; the previous patch worked only for SEEK_CUR
  * [2822] allow dvd sources that have no audio
* Sun Sep 13 2009 pascal.bleser@opensuse.org
- update to rev 2815:
  * [2796] set use m4v preference enabled by default
  * [2797] fix PAR issue with DV For some (maybe all) DV, ffmpeg doesn't give us the sample_aspect_ratio in the context; so when it's missing, try looking it up in the AVStream info
  * [2811] improve "auto" audio selection picks the "best" audio given the input codec and output formats
  * [2812] show the correct audio codec in the audio list when it has been changed because of incompatibility with source codec or output format
  * [2813] fix initialization of chapter list when editing queued job Chapter titles the user entered were lost when editing a queued job
  * [2814] fix a Gtk-CRITICAL error when editing chapter names
  * [2815] dvdnav: read error recovery - patch libdvdnav seek to guarantee the position will move forward when making a seek request to a position that is after the current position - when a read error is detected, seek forward and retry
* Sat Sep  5 2009 pascal.bleser@opensuse.org
- new package
